@@ -8,8 +8,10 @@ from typing import List, Dict
 
 from fastapi import APIRouter, status
 from sqlalchemy import update as _update
+from sqlalchemy.dialects.postgresql import Insert as _insert
+from sqlalchemy.exc import SQLAlchemyError
 
-from fidesapi import db_session
+from fidesapi import db_session, errors
 from fidesapi.sql_models import sql_model_map, SqlAlchemyBase
 from fideslang import model_map
 
@@ -20,15 +22,27 @@ def get_resource_type(router: APIRouter) -> str:
 
 
 # CRUD Functions
-def create_resource(sql_resource: SqlAlchemyBase) -> None:
+def create_resource(sql_model: SqlAlchemyBase, sql_resource: SqlAlchemyBase) -> Dict:
     """Create a resource in the database."""
+    try:
+        get_resource(sql_model, sql_resource.fides_key)
+    except errors.NotFoundError:
+        pass
+    else:
+        raise errors.AlreadyExistsError(sql_model.__name__, sql_resource.fides_key)
+
     session = db_session.create_session()
     try:
         session.add(sql_resource)
         session.commit()
+    except SQLAlchemyError:
+        session.rollback()
+        raise errors.QueryError()
     finally:
         session.close()
 
+    return get_resource(sql_model, sql_resource.fides_key)
+
 
 def get_resource(sql_model: SqlAlchemyBase, fides_key: str) -> Dict:
     """
@@ -37,10 +51,20 @@ def get_resource(sql_model: SqlAlchemyBase, fides_key: str) -> Dict:
     session = db_session.create_session()
     try:
         sql_resource = (
-            session.query(sql_model).filter(sql_model.fides_key == fides_key).first()
+            session.query(sql_model)
+            .filter(sql_model.fides_key == fides_key)
+            .limit(1)
+            .first()
         )
+    except SQLAlchemyError:
+        session.rollback()
+        raise errors.QueryError()
     finally:
         session.close()
+
+    if sql_resource is None:
+        raise errors.NotFoundError(sql_model.__name__, fides_key)
+
     return sql_resource
 
 
@@ -51,13 +75,20 @@ def list_resource(sql_model: SqlAlchemyBase) -> List:
     session = db_session.create_session()
     try:
         sql_resource = session.query(sql_model).all()
+    except SQLAlchemyError:
+        session.rollback()
+        raise errors.QueryError()
     finally:
         session.close()
+
     return sql_resource
 
 
-def update_resource(sql_model: SqlAlchemyBase, resource_dict: Dict, fides_key: str):
+def update_resource(
+    sql_model: SqlAlchemyBase, resource_dict: Dict, fides_key: str
+) -> Dict:
     """Update a resource in the database by its fides_key."""
+    get_resource(sql_model, fides_key)
     session = db_session.create_session()
     try:
         session.execute(
@@ -66,29 +97,50 @@ def update_resource(sql_model: SqlAlchemyBase, resource_dict: Dict, fides_key: s
             .values(resource_dict)
         )
         session.commit()
+    except SQLAlchemyError:
+        session.rollback()
+        raise errors.QueryError()
     finally:
         session.close()
 
-    result_sql_resource = get_resource(sql_model, fides_key)
-    if not result_sql_resource:
-        return {"error": {"message": f"{fides_key} is not an existing fides_key!"}}
+    return get_resource(sql_model, resource_dict.get("fides_key"))
 
-    return result_sql_resource
+
+def upsert_resources(sql_model: SqlAlchemyBase, resource_dicts: List[Dict]) -> None:
+    """
+    Insert new resources into the database. If a resource already exists,
+    update it by it's fides_key.
+    """
+    session = db_session.create_session()
+    try:
+        insert_stmt = _insert(sql_model).values(resource_dicts)
+        session.execute(
+            insert_stmt.on_conflict_do_update(
+                index_elements=["fides_key"],
+                set_=insert_stmt.excluded,
+            )
+        )
+        session.commit()
+    except SQLAlchemyError:
+        session.rollback()
+    finally:
+        session.close()
 
 
 def delete_resource(sql_model: SqlAlchemyBase, fides_key: str) -> Dict:
     """Delete a resource by its fides_key."""
-    result_sql_resource = get_resource(sql_model, fides_key)
-    if not result_sql_resource:
-        return {"error": {"message": f"{fides_key} is not an existing fides_key!"}}
-
+    sql_resource = get_resource(sql_model, fides_key)
     session = db_session.create_session()
     try:
-        session.delete(result_sql_resource)
+        session.delete(sql_resource)
         session.commit()
+    except SQLAlchemyError:
+        session.rollback()
+        raise errors.QueryError()
     finally:
         session.close()
-    return {}
+
+    return sql_resource
 
 
 # CRUD Endpoints
@@ -108,9 +160,9 @@ for resource_type, resource_model in model_map.items():
         resource_type: str = get_resource_type(router),
     ) -> Dict:
         """Create a resource."""
-        sql_resource = sql_model_map[resource_type](**resource.dict())
-        create_resource(sql_resource)
-        return sql_resource
+        sql_model = sql_model_map[resource_type]
+        sql_resource = sql_model(**resource.dict())
+        return create_resource(sql_model, sql_resource)
 
     @router.get("/", response_model=List[resource_model], name="List")
     async def ls(  # pylint: disable=invalid-name
@@ -118,8 +170,7 @@ for resource_type, resource_model in model_map.items():
     ) -> List:
         """Get a list of all of the resources of this type."""
         sql_model = sql_model_map[resource_type]
-        query_result = list_resource(sql_model)
-        return query_result
+        return list_resource(sql_model)
 
     @router.get("/{fides_key}", response_model=resource_model)
     async def get(
@@ -127,8 +178,7 @@ for resource_type, resource_model in model_map.items():
     ) -> Dict:
         """Get a resource by its fides_key."""
         sql_model = sql_model_map[resource_type]
-        query_result = get_resource(sql_model, fides_key)
-        return query_result
+        return get_resource(sql_model, fides_key)
 
     @router.post("/{fides_key}", response_model=resource_model)
     async def update(
@@ -139,18 +189,18 @@ for resource_type, resource_model in model_map.items():
         """Update a resource by its fides_key."""
         sql_model = sql_model_map[resource_type]
         resource_dict = resource.dict()
-        query_result = update_resource(sql_model, resource_dict, fides_key)
-        return query_result
+        return update_resource(sql_model, resource_dict, fides_key)
 
-    @router.delete("/{fides_key}", status_code=status.HTTP_204_NO_CONTENT)
+    @router.delete("/{fides_key}")
     async def delete(
         fides_key: str, resource_type: str = get_resource_type(router)
     ) -> Dict:
         """Delete a resource by its fides_key."""
         sql_model = sql_model_map[resource_type]
-        delete_resource(sql_model, fides_key)
+        query_result = delete_resource(sql_model, fides_key)
         return {
-            "Message": f"Resource with fides_key: {fides_key} deleted successfully!"
+            "message": "resource deleted",
+            "resource": query_result,
         }
 
     routers += [router]
