@@ -7,6 +7,7 @@ from typing import Callable, Optional
 import sqlalchemy as sa
 import sqlalchemy.orm as orm
 from sqlalchemy.orm import Session
+from fidesapi.errors import DatabaseUnavailableError
 
 FACTORY: Optional[Callable[[], Session]] = None
 
@@ -32,7 +33,7 @@ def create_session() -> Session:
     global FACTORY  # pylint: disable=global-statement
 
     if not FACTORY:
-        raise Exception("You must call global_init() before using this method.")
+        raise DatabaseUnavailableError()
 
     session: Session = FACTORY()
     session.expire_on_commit = False
